@@ -1,6 +1,6 @@
 ## src/common/gpg.py
 ##
-## Copyright (C) 2003-2017 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2003-2014 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2005 Alex Mauer <hawke AT hawkesnest.net>
 ## Copyright (C) 2005-2006 Nikos Kouremenos <kourem AT gmail.com>
 ## Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
@@ -23,19 +23,18 @@
 ##
 
 import os
-import locale
 import logging
-import gajim
+from gajim.common import app
 
-if gajim.HAVE_GPG:
+if app.HAVE_GPG:
     import gnupg
     gnupg.logger = logging.getLogger('gajim.c.gnupg')
 
     class GnuPG(gnupg.GPG):
         def __init__(self):
-            use_agent = gajim.config.get('use_gpg_agent')
-            gnupg.GPG.__init__(self, gpgbinary=gajim.GPG_BINARY, use_agent=use_agent)
-            encoding = gajim.config.get('pgp_encoding')
+            use_agent = app.config.get('use_gpg_agent')
+            gnupg.GPG.__init__(self, gpgbinary=app.GPG_BINARY, use_agent=use_agent)
+            encoding = app.config.get('pgp_encoding')
             if encoding:
                 self.encoding = encoding
             self.decode_errors = 'replace'
@@ -112,6 +111,7 @@ if gajim.HAVE_GPG:
         def get_keys(self, secret=False):
             keys = {}
             result = super(GnuPG, self).list_keys(secret=secret)
+
             for key in result:
                 # Take first not empty uid
                 keys[key['keyid'][8:]] = [uid for uid in key['uids'] if uid][0]
