@@ -4,7 +4,7 @@
 ## Copyright (C) 2006 Dimitur Kirov <dkirov AT gmail.com>
 ## Copyright (C) 2006-2007 Jean-Marie Traissard <jim AT lapin.org>
 ##                         Nikos Kouremenos <kourem AT gmail.com>
-## Copyright (C) 2006-2017 Yann Leboulanger <asterix AT lagaule.org>
+## Copyright (C) 2006-2014 Yann Leboulanger <asterix AT lagaule.org>
 ## Copyright (C) 2007 Stephan Erb <steve-e AT h3c.de>
 ## Copyright (C) 2008 Jonathan Schleifer <js-gajim AT webkeks.org>
 ##
@@ -29,53 +29,36 @@
 ## the same can be said for history_window.py
 
 import os
-
-if os.name == 'nt':
-    import warnings
-    warnings.filterwarnings(action='ignore')
-
-    if os.path.isdir('gtk'):
-        # Used to create windows installer with GTK included
-        paths = os.environ['PATH']
-        list_ = paths.split(';')
-        new_list = []
-        for p in list_:
-            if p.find('gtk') < 0 and p.find('GTK') < 0:
-                new_list.append(p)
-        new_list.insert(0, 'gtk/lib')
-        new_list.insert(0, 'gtk/bin')
-        os.environ['PATH'] = ';'.join(new_list)
-        os.environ['GTK_BASEPATH'] = 'gtk'
-
 import sys
-import signal
-import gtk
-import gobject
+import gi
+gi.require_version('Gtk', '3.0')
+from gi.repository import Gtk
+from gi.repository import Gdk
+from gi.repository import GLib
 import time
-import locale
 
 import getopt
-from common import i18n
+from gajim.common import i18n
 
 def parseOpts():
     config_path = None
 
     try:
-        shortargs = 'hc:'
-        longargs = 'help config-path='
+        shortargs = 'hvc:l:p:'
+        longargs = 'help verbose config-path= loglevel= profile='
         opts = getopt.getopt(sys.argv[1:], shortargs, longargs.split())[0]
-    except getopt.error, msg:
-        print str(msg)
-        print 'for help use --help'
+    except getopt.error as msg:
+        print(str(msg))
+        print('for help use --help')
         sys.exit(2)
     for o, a in opts:
         if o in ('-h', '--help'):
-            print _('Usage:') + \
+            print(_('Usage:') + \
                 '\n  gajim-history-manager [options] filename\n\n' + \
                 _('Options:') + \
                 '\n  -h, --help         ' + \
                     _('Show this help message and exit') + \
-                '\n  -c, --config-path  ' + _('Set logs directory') + '\n'
+                '\n  -c, --config-path  ' + _('Choose folder for logfile') + '\n')
             sys.exit()
         elif o in ('-c', '--config-path'):
             config_path = a
@@ -84,27 +67,23 @@ def parseOpts():
 config_path = parseOpts()
 del parseOpts
 
-import common.configpaths
-common.configpaths.gajimpaths.init(config_path)
+import gajim.common.configpaths
+gajim.common.configpaths.gajimpaths.init(config_path)
 del config_path
-common.configpaths.gajimpaths.init_profile()
-from common import gajim
-import gtkgui_helpers
-from common.logger import LOG_DB_PATH, constants
+from gajim.common import app
+from gajim import gtkgui_helpers
+from gajim.common.logger import LOG_DB_PATH, JIDConstant, KindConstant
+from gajim.common import helpers
+from gajim import dialogs
 
-#FIXME: constants should implement 2 way mappings
-status = dict((constants.__dict__[i], i[5:].lower()) for i in \
-        constants.__dict__.keys() if i.startswith('SHOW_'))
-from common import helpers
-import dialogs
+from enum import IntEnum, unique
 
-# time, message, subject
-(
-C_UNIXTIME,
-C_MESSAGE,
-C_SUBJECT,
-C_NICKNAME
-) = range(2, 6)
+@unique
+class Column(IntEnum):
+    UNIXTIME = 2
+    MESSAGE = 3
+    SUBJECT = 4
+    NICKNAME = 5
 
 
 import sqlite3 as sqlite
@@ -114,12 +93,12 @@ class HistoryManager:
     def __init__(self):
         pixs = []
         for size in (16, 32, 48, 64, 128):
-            pix = gtkgui_helpers.get_icon_pixmap('gajim', size)
+            pix = gtkgui_helpers.get_icon_pixmap('org.gajim.Gajim', size)
             if pix:
                 pixs.append(pix)
         if pixs:
             # set the icon to all windows
-            gtk.window_set_default_icon_list(*pixs)
+            Gtk.Window.set_default_icon_list(pixs)
 
         if not os.path.exists(LOG_DB_PATH):
             dialogs.ErrorDialog(_('Cannot find history logs database'),
@@ -157,12 +136,12 @@ class HistoryManager:
         xml.connect_signals(self)
 
     def _init_jids_listview(self):
-        self.jids_liststore = gtk.ListStore(str, str)  # jid, jid_id
+        self.jids_liststore = Gtk.ListStore(str, str)  # jid, jid_id
         self.jids_listview.set_model(self.jids_liststore)
-        self.jids_listview.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
+        self.jids_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
-        renderer_text = gtk.CellRendererText()  # holds jid
-        col = gtk.TreeViewColumn(_('Jabber ID'), renderer_text, text=0)
+        renderer_text = Gtk.CellRendererText()  # holds jid
+        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=0)
         self.jids_listview.append_column(col)
 
         self.jids_listview.get_selection().connect('changed',
@@ -170,37 +149,37 @@ class HistoryManager:
 
     def _init_logs_listview(self):
         # log_line_id(HIDDEN), jid_id(HIDDEN), time, message, subject, nickname
-        self.logs_liststore = gtk.ListStore(str, str, str, str, str, str)
+        self.logs_liststore = Gtk.ListStore(str, str, str, str, str, str)
         self.logs_listview.set_model(self.logs_liststore)
-        self.logs_listview.get_selection().set_mode(gtk.SELECTION_MULTIPLE)
+        self.logs_listview.get_selection().set_mode(Gtk.SelectionMode.MULTIPLE)
 
-        renderer_text = gtk.CellRendererText()  # holds time
-        col = gtk.TreeViewColumn(_('Date'), renderer_text, text=C_UNIXTIME)
+        renderer_text = Gtk.CellRendererText()  # holds time
+        col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
-        col.set_sort_column_id(C_UNIXTIME)
+        col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
         self.logs_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds nickname
-        col = gtk.TreeViewColumn(_('Nickname'), renderer_text, text=C_NICKNAME)
+        renderer_text = Gtk.CellRendererText()  # holds nickname
+        col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
         # user can click this header and sort
-        col.set_sort_column_id(C_NICKNAME)
+        col.set_sort_column_id(Column.NICKNAME)
         col.set_resizable(True)
         col.set_visible(False)
         self.nickname_col_for_logs = col
         self.logs_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds message
-        col = gtk.TreeViewColumn(_('Message'), renderer_text, markup=C_MESSAGE)
+        renderer_text = Gtk.CellRendererText()  # holds message
+        col = Gtk.TreeViewColumn(_('Message'), renderer_text, markup=Column.MESSAGE)
         # user can click this header and sort
-        col.set_sort_column_id(C_MESSAGE)
+        col.set_sort_column_id(Column.MESSAGE)
         col.set_resizable(True)
         self.message_col_for_logs = col
         self.logs_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds subject
-        col = gtk.TreeViewColumn(_('Subject'), renderer_text, text=C_SUBJECT)
-        col.set_sort_column_id(C_SUBJECT)  # user can click this header and sort
+        renderer_text = Gtk.CellRendererText()  # holds subject
+        col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
+        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
         col.set_resizable(True)
         col.set_visible(False)
         self.subject_col_for_logs = col
@@ -208,54 +187,54 @@ class HistoryManager:
 
     def _init_search_results_listview(self):
         # log_line_id (HIDDEN), jid, time, message, subject, nickname
-        self.search_results_liststore = gtk.ListStore(str, str, str, str, str,
+        self.search_results_liststore = Gtk.ListStore(int, str, str, str, str,
             str)
         self.search_results_listview.set_model(self.search_results_liststore)
 
-        renderer_text = gtk.CellRendererText()  # holds JID (who said this)
-        col = gtk.TreeViewColumn(_('JID'), renderer_text, text=1)
+        renderer_text = Gtk.CellRendererText()  # holds JID (who said this)
+        col = Gtk.TreeViewColumn(_('JID'), renderer_text, text=1)
         col.set_sort_column_id(1)  # user can click this header and sort
         col.set_resizable(True)
         self.search_results_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds time
-        col = gtk.TreeViewColumn(_('Date'), renderer_text, text=C_UNIXTIME)
+        renderer_text = Gtk.CellRendererText()  # holds time
+        col = Gtk.TreeViewColumn(_('Date'), renderer_text, text=Column.UNIXTIME)
         # user can click this header and sort
-        col.set_sort_column_id(C_UNIXTIME)
+        col.set_sort_column_id(Column.UNIXTIME)
         col.set_resizable(True)
         self.search_results_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds message
-        col = gtk.TreeViewColumn(_('Message'), renderer_text, text=C_MESSAGE)
-        col.set_sort_column_id(C_MESSAGE)  # user can click this header and sort
+        renderer_text = Gtk.CellRendererText()  # holds message
+        col = Gtk.TreeViewColumn(_('Message'), renderer_text, text=Column.MESSAGE)
+        col.set_sort_column_id(Column.MESSAGE)  # user can click this header and sort
         col.set_resizable(True)
         self.search_results_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds subject
-        col = gtk.TreeViewColumn(_('Subject'), renderer_text, text=C_SUBJECT)
-        col.set_sort_column_id(C_SUBJECT)  # user can click this header and sort
+        renderer_text = Gtk.CellRendererText()  # holds subject
+        col = Gtk.TreeViewColumn(_('Subject'), renderer_text, text=Column.SUBJECT)
+        col.set_sort_column_id(Column.SUBJECT)  # user can click this header and sort
         col.set_resizable(True)
         self.search_results_listview.append_column(col)
 
-        renderer_text = gtk.CellRendererText()  # holds nickname
-        col = gtk.TreeViewColumn(_('Nickname'), renderer_text, text=C_NICKNAME)
+        renderer_text = Gtk.CellRendererText()  # holds nickname
+        col = Gtk.TreeViewColumn(_('Nickname'), renderer_text, text=Column.NICKNAME)
         # user can click this header and sort
-        col.set_sort_column_id(C_NICKNAME)
+        col.set_sort_column_id(Column.NICKNAME)
         col.set_resizable(True)
         self.search_results_listview.append_column(col)
 
     def on_history_manager_window_delete_event(self, widget, event):
         if not self.AT_LEAST_ONE_DELETION_DONE:
-            gtk.main_quit()
+            Gtk.main_quit()
             return
 
         def on_yes(clicked):
             self.cur.execute('VACUUM')
             self.con.commit()
-            gtk.main_quit()
+            Gtk.main_quit()
 
         def on_no():
-            gtk.main_quit()
+            Gtk.main_quit()
 
         dialog = dialogs.YesNoDialog(
             _('Do you want to clean up the database? '
@@ -263,7 +242,7 @@ class HistoryManager:
             _('Normally allocated database size will not be freed, '
                 'it will just become reusable. If you really want to reduce '
                 'database filesize, click YES, else click NO.'
-                '\n\nIn case you click YES, please wait...'),
+                '\n\nIn case you click YES, please wait…'),
             on_response_yes=on_yes, on_response_no=on_no)
         dialog.set_title(_('Database Cleanup'))
         button_box = dialog.get_children()[0].get_children()[1]
@@ -273,11 +252,11 @@ class HistoryManager:
         # get those jids that have at least one entry in logs
         self.cur.execute('SELECT jid, jid_id FROM jids WHERE jid_id IN ('
                 'SELECT distinct logs.jid_id FROM logs) ORDER BY jid')
-        # list of tupples: [(u'aaa@bbb',), (u'cc@dd',)]
+        # list of tuples: [('aaa@bbb',), ('cc@dd',)]
         rows = self.cur.fetchall()
         for row in rows:
             self.jids_already_in.append(row[0])  # jid
-            self.jids_liststore.append(row)  # jid, jid_id
+            self.jids_liststore.append([row[0], str(row[1])])  # jid, jid_id
 
     def on_jids_listview_selection_changed(self, widget, data=None):
         liststore, list_of_paths = self.jids_listview.get_selection()\
@@ -294,13 +273,13 @@ class HistoryManager:
 
         list_of_rowrefs = []
         for path in list_of_paths:  # make them treerowrefs (it's needed)
-            list_of_rowrefs.append(gtk.TreeRowReference(liststore, path))
+            list_of_rowrefs.append(Gtk.TreeRowReference.new(liststore, path))
 
         for rowref in list_of_rowrefs:  # FILL THE STORE, for all rows selected
             path = rowref.get_path()
             if path is None:
                 continue
-            jid = liststore[path][0].decode('utf-8')  # jid
+            jid = liststore[path][0]  # jid
             self._fill_logs_listview(jid)
 
     def _get_jid_id(self, jid):
@@ -341,7 +320,7 @@ class HistoryManager:
         possible_room_jid = jid.split('/', 1)[0]
 
         self.cur.execute('SELECT jid_id FROM jids WHERE jid = ? AND type = ?',
-                (possible_room_jid, constants.JID_ROOM_TYPE))
+                (possible_room_jid, JIDConstant.ROOM_TYPE))
         row = self.cur.fetchone()
         if row is None:
             return False
@@ -356,7 +335,7 @@ class HistoryManager:
         row = self.cur.fetchone()
         if row is None:
             raise
-        elif row[0] == constants.JID_ROOM_TYPE:
+        elif row[0] == JIDConstant.ROOM_TYPE:
             return True
         else:  # normal type
             return False
@@ -393,38 +372,36 @@ class HistoryManager:
             log_line_id, jid_id, time_, kind, message, subject, nickname, \
                 show = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_))
-                    ).decode(locale.getpreferredencoding())
+                time_ = time.strftime('%x', time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
                 color = None
-                if kind in (constants.KIND_SINGLE_MSG_RECV,
-                constants.KIND_CHAT_MSG_RECV, constants.KIND_GC_MSG):
+                if kind in (KindConstant.SINGLE_MSG_RECV,
+                KindConstant.CHAT_MSG_RECV, KindConstant.GC_MSG):
                     # it is the other side
-                    color = gajim.config.get('inmsgcolor')  # so incoming color
-                elif kind in (constants.KIND_SINGLE_MSG_SENT,
-                constants.KIND_CHAT_MSG_SENT):  # it is us
-                    color = gajim.config.get('outmsgcolor')  # so outgoing color
-                elif kind in (constants.KIND_STATUS,
-                constants.KIND_GCSTATUS):  # is is statuses
+                    color = app.config.get('inmsgcolor')  # so incoming color
+                elif kind in (KindConstant.SINGLE_MSG_SENT,
+                KindConstant.CHAT_MSG_SENT):  # it is us
+                    color = app.config.get('outmsgcolor')  # so outgoing color
+                elif kind in (KindConstant.STATUS,
+                KindConstant.GCSTATUS):  # is is statuses
                     # so status color
-                    color = gajim.config.get('statusmsgcolor')
+                    color = app.config.get('statusmsgcolor')
                     # include status into (status) message
                     if message is None:
                         message = ''
                     else:
                         message = ' : ' + message
-                    message = helpers.get_uf_show(gajim.SHOW_LIST[show]) + \
+                    message = helpers.get_uf_show(app.SHOW_LIST[show]) + \
                         message
 
                 message_ = '<span'
                 if color:
                     message_ += ' foreground="%s"' % color
-                message_ += '>%s</span>' % \
-                        gobject.markup_escape_text(message)
-                self.logs_liststore.append((log_line_id, jid_id, time_,
-                    message_, subject, nickname))
+                message_ += '>%s</span>' % GLib.markup_escape_text(message)
+                self.logs_liststore.append((str(log_line_id), str(jid_id),
+                    time_, message_, subject, nickname))
 
     def _fill_search_results_listview(self, text):
         """
@@ -447,8 +424,7 @@ class HistoryManager:
             # log_line_id, jid (from jid_id), time, message, subject, nickname
             log_line_id, jid_id, time_, message, subject, nickname = row
             try:
-                time_ = time.strftime('%x', time.localtime(float(time_))
-                    ).decode(locale.getpreferredencoding())
+                time_ = time.strftime('%x', time.localtime(float(time_)))
             except ValueError:
                 pass
             else:
@@ -460,20 +436,20 @@ class HistoryManager:
     def on_logs_listview_key_press_event(self, widget, event):
         liststore, list_of_paths = self.logs_listview.get_selection()\
                 .get_selected_rows()
-        if event.keyval == gtk.keysyms.Delete:
+        if event.keyval == Gdk.KEY_Delete:
             self._delete_logs(liststore, list_of_paths)
 
     def on_listview_button_press_event(self, widget, event):
         if event.button == 3:  # right click
             xml = gtkgui_helpers.get_gtk_builder('history_manager.ui',
                 'context_menu')
-            if gtk.Buildable.get_name(widget) != 'jids_listview':
+            if Gtk.Buildable.get_name(widget) != 'jids_listview':
                 xml.get_object('export_menuitem').hide()
             xml.get_object('delete_menuitem').connect('activate',
                     self.on_delete_menuitem_activate, widget)
 
             xml.connect_signals(self)
-            xml.get_object('context_menu').popup(None, None, None,
+            xml.get_object('context_menu').popup(None, None, None, None,
                     event.button, event.time)
             return True
 
@@ -483,12 +459,12 @@ class HistoryManager:
         xml.connect_signals(self)
 
         dlg = xml.get_object('filechooserdialog')
-        dlg.set_title(_('Exporting History Logs...'))
-        dlg.set_current_folder(gajim.HOME_DIR)
+        dlg.set_title(_('Exporting History Logs…'))
+        dlg.set_current_folder(app.HOME_DIR)
         dlg.props.do_overwrite_confirmation = True
         response = dlg.run()
 
-        if response == gtk.RESPONSE_OK:  # user want us to export ;)
+        if response == Gtk.ResponseType.OK:  # user want us to export ;)
             liststore, list_of_paths = self.jids_listview.get_selection()\
                     .get_selected_rows()
             path_to_file = dlg.get_filename()
@@ -498,7 +474,7 @@ class HistoryManager:
         dlg.destroy()
 
     def on_delete_menuitem_activate(self, widget, listview):
-        widget_name = gtk.Buildable.get_name(listview)
+        widget_name = Gtk.Buildable.get_name(listview)
         liststore, list_of_paths = listview.get_selection().get_selected_rows()
         if widget_name == 'jids_listview':
             self._delete_jid_logs(liststore, list_of_paths)
@@ -510,7 +486,7 @@ class HistoryManager:
     def on_jids_listview_key_press_event(self, widget, event):
         liststore, list_of_paths = self.jids_listview.get_selection()\
                 .get_selected_rows()
-        if event.keyval == gtk.keysyms.Delete:
+        if event.keyval == Gdk.KEY_Delete:
             self._delete_jid_logs(liststore, list_of_paths)
 
     def _export_jids_logs_to_file(self, liststore, list_of_paths, path_to_file):
@@ -520,7 +496,7 @@ class HistoryManager:
 
         list_of_rowrefs = []
         for path in list_of_paths:  # make them treerowrefs (it's needed)
-            list_of_rowrefs.append(gtk.TreeRowReference(liststore, path))
+            list_of_rowrefs.append(Gtk.TreeRowReference.new(liststore, path))
 
         for rowref in list_of_rowrefs:
             path = rowref.get_path()
@@ -542,21 +518,20 @@ class HistoryManager:
             # in store: time, kind, message, contact_name FROM logs
             # in text: JID or You or nickname (if it's gc_msg), time, message
             time_, kind, message, nickname = row
-            if kind in (constants.KIND_SINGLE_MSG_RECV,
-                    constants.KIND_CHAT_MSG_RECV):
+            if kind in (KindConstant.SINGLE_MSG_RECV,
+                    KindConstant.CHAT_MSG_RECV):
                 who = self._get_jid_from_jid_id(jid_id)
-            elif kind in (constants.KIND_SINGLE_MSG_SENT,
-                    constants.KIND_CHAT_MSG_SENT):
+            elif kind in (KindConstant.SINGLE_MSG_SENT,
+                    KindConstant.CHAT_MSG_SENT):
                 who = _('You')
-            elif kind == constants.KIND_GC_MSG:
+            elif kind == KindConstant.GC_MSG:
                 who = nickname
             else:  # status or gc_status. do not save
                 #print kind
                 continue
 
             try:
-                time_ = time.strftime('%c', time.localtime(float(time_))
-                    ).decode(locale.getpreferredencoding())
+                time_ = time.strftime('%c', time.localtime(float(time_)))
             except ValueError:
                 pass
 
@@ -572,7 +547,7 @@ class HistoryManager:
             # delete all rows from db that match jid_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
-                list_of_rowrefs.append(gtk.TreeRowReference(liststore, path))
+                list_of_rowrefs.append(Gtk.TreeRowReference.new(liststore, path))
 
             for rowref in list_of_rowrefs:
                 path = rowref.get_path()
@@ -598,13 +573,13 @@ class HistoryManager:
 
         if paths_len == 1:
             jid_id = '<i>%s</i>' % liststore[list_of_paths[0]][0]
-            pri_text = _('Do you really want to delete the logs of %(jid)s?') \
+            pri_text = _('Do you wish to delete all correspondence with %(jid)s?') \
                 % {'jid': jid_id}
         else:
             pri_text = _(
-                'Do you really want to delete logs of the selected contacts?')
+                'Do you wish to delete all correspondence with the selected contacts?')
         dialog = dialogs.ConfirmationDialog('',
-            _('This is an irreversible operation.'), on_response_ok=(on_ok,
+            _('This can not be undone.'), on_response_ok=(on_ok,
             liststore, list_of_paths))
         dialog.set_title(_('Deletion Confirmation'))
         dialog.set_markup(pri_text)
@@ -621,7 +596,7 @@ class HistoryManager:
             # delete rows from db that match log_line_id
             list_of_rowrefs = []
             for path in list_of_paths:  # make them treerowrefs (it's needed)
-                list_of_rowrefs.append(gtk.TreeRowReference(liststore, path))
+                list_of_rowrefs.append(Gtk.TreeRowReference.new(liststore, path))
 
             for rowref in list_of_rowrefs:
                 path = rowref.get_path()
@@ -651,7 +626,7 @@ class HistoryManager:
         dialog.set_transient_for(self.window)
 
     def on_search_db_button_clicked(self, widget):
-        text = self.search_entry.get_text().decode('utf-8')
+        text = self.search_entry.get_text()
         if not text:
             return
 
@@ -664,12 +639,12 @@ class HistoryManager:
     def on_search_results_listview_row_activated(self, widget, path, column):
         # get log_line_id, jid_id from row we double clicked
         log_line_id = self.search_results_liststore[path][0]
-        jid = self.search_results_liststore[path][1].decode('utf-8')
+        jid = self.search_results_liststore[path][1]
         # make it string as in gtk liststores I have them all as strings
         # as this is what db returns so I don't have to fight with types
         jid_id = self._get_jid_id(jid)
 
-        iter_ = self.jids_liststore.get_iter_root()
+        iter_ = self.jids_liststore.get_iter_first()
         while iter_:
             # self.jids_liststore[iter_][1] holds jid_ids
             if self.jids_liststore[iter_][1] == jid_id:
@@ -682,7 +657,7 @@ class HistoryManager:
         path = self.jids_liststore.get_path(iter_)
         self.jids_listview.set_cursor(path)
 
-        iter_ = self.logs_liststore.get_iter_root()
+        iter_ = self.logs_liststore.get_iter_first()
         while iter_:
             # self.logs_liststore[iter_][0] holds lon_line_ids
             if self.logs_liststore[iter_][0] == log_line_id:
@@ -692,7 +667,15 @@ class HistoryManager:
         path = self.logs_liststore.get_path(iter_)
         self.logs_listview.scroll_to_cell(path)
 
-if __name__ == '__main__':
-    signal.signal(signal.SIGINT, signal.SIG_DFL)  # ^C exits the application
+
+def main():
+    if sys.platform != 'win32':
+        if os.geteuid() == 0:
+            sys.exit("You must not launch gajim as root, it is insecure.")
+
     HistoryManager()
-    gtk.main()
+    Gtk.main()
+
+
+if __name__ == '__main__':
+    main()
